exitOnRetryThresholdReached property
Whether the SDK quits instead of showing a contact support button when the retryThreshold was reached.
Implementation
bool? exitOnRetryThresholdReached;
Whether the SDK quits instead of showing a contact support button when the retryThreshold was reached.
bool? exitOnRetryThresholdReached;